==> pwsafe-2.0-src.zip: pwsafe-2.0-src/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by PasswordSafe.rc
//
#define ID_BROWSE                       3
#define ID_CREATE_DB                    4
#define IDD_ABOUTBOX                    100
#define IDD_FIND                        101
#define IDD_PASSWORDSAFE_DIALOG         102
#define IDS_OUTPUTFILE                  102
#define ID_SYSMENU_ALWAYSONTOP          102
#define IDS_TEMPFILE                    103
#define IDS_COMPANY                     104
#define IDS_STATCOMPANY                 105
#define IDS_STATMESSAGE                 106
#define IDS_ALWAYSONTOP                 107
#define IDR_MAINFRAME                   128
#define IDR_ACCS                        128
#define IDD_KEYCHANGE_DIALOG            131
#define IDD_PASSKEYSETUP                132
#define IDD_SECURECLEAR                 133
#define IDI_IBUBBLE                     134
#define IDD_PASSKEYENTRY_FIRST          135
#define IDD_CONFIRMDELETE_DIALOG        136
#define IDD_OPTIONS                     137
#define IDD_EDIT                        139
#define IDD_MINIMIZECLEAR_DIALOG        141
#define IDD_ADD                         142
#define IDD_TRYAGAIN                    143
#define IDD_REMIND_SAVE                 144
#define IDB_PSLOGO                      148
#define IDB_CLOGO                       150
#define IDB_CTEXT                       151
#define IDD_CRYPTKEYENTRY               160
#define IDR_MAINMENU                    162
#define IDR_POPMENU                     166
#define IDD_QUERYSETDEF                 167
#define IDR_POPGROUP                    168
#define IDR_POPTREE                     169
#define IDD_QUERYADDNAME                183
#define IDD_USERNAMEENTRY               184
#define IDD_PASSKEYENTRY                185
#define IDR_MAINBAR                     187
#define IDB_CLOGO_SMALL                 189
#define IDI_CORNERICON                  191
#define IDD_PS_SECURITY                 194
#define IDD_PS_DISPLAY                  195
#define IDD_PS_USERNAME                 196
#define IDD_PS_PASSWORDPOLICY           197
#define IDD_PS_MISC                     198
#define IDB_NODE                        199
#define IDB_LEAF                        200
#define IDD_EXPORT_TEXT                 204
#define IDC_PASSWORD                    1000
#define IDC_ITEMLIST                    1000
#define IDC_OLDPASSKEY                  1001
#define IDC_NEWPASSKEY                  1002
#define IDC_CONFIRMNEW                  1003
#define IDC_TITLE                       1004
#define IDC_USERNAME                    1005
#define IDC_NOTES                       1006
#define IDC_SHOWPASSWORD                1008
#define IDC_CLEARCHECK                  1009
#define IDC_PASSKEY                     1010
#define IDC_DELITEM                     1010
#define IDC_VERIFY                      1012
#define IDC_CONFIRMDELETE               1014
#define IDC_CLEARBOARD                  1015
#define IDC_CONFIRMCOPY                 1016
#define IDC_TRYAGAIN                    1024
#define IDC_QUIT                        1025
#define IDC_OPEN                        1027
#define IDC_RANDOM                      1028
#define IDC_LOCKBASE                    1029
#define IDC_SAVEMINIMIZE                1030
#define IDC_DEFPWSHOW                   1031
#define IDC_DEFPWSHOWINEDIT             1031
#define IDC_USEDEFUSER                  1032
#define IDC_QUERYSETDEF                 1033
#define IDC_QUERYADDNAME                1034
#define IDC_DEFPWSHOWINLIST             1035
#define IDC_CRYPTKEY1                   1045
#define IDC_CRYPTKEY2                   1046
#define IDC_DEFUSERNAME                 1049
#define IDC_STATIC_USERNAME             1050
#define IDC_DEFPWLENGTH                 1051
#define IDC_MESSAGE                     1052
#define IDC_STATIC_DEFPWLENGTH          1052
#define IDC_QUERYCHECK                  1053
#define IDC_STATIC_RULES                1053
#define IDC_STATIC_MINLOWERCASE         1054
#define IDC_MAKEDEF                     1055
#define IDC_STATIC_MINUPPERCASE         1055
#define IDC_NEW                         1056
#define IDC_STATIC_MINDIGITS            1056
#define IDC_STATIC_ICON1                1057
#define IDC_STATIC_MINSYMBOLS           1057
#define IDC_MINLOWERCASE                1058
#define IDC_MINUPPERCASE                1059
#define IDC_STATIC_ICON2                1060
#define IDC_STATIC_LOGO                 1060
#define IDC_MINDIGITS                   1060
#define IDC_STATIC_ICON3                1061
#define IDC_MINSYMBOLS                  1061
#define IDC_FIND_TEXT                   1062
#define IDC_FIND_CS                     1063
#define IDC_STATUS                      1064
#define IDC_ALWAYSONTOP                 1065
#define IDC_STATIC_LOGOTEXT             1066
#define IDC_SAVEIMMEDIATELY             1066
#define IDC_SPIN1                       1068
#define IDC_USELOWERCASE                1069
#define IDC_USEUPPERCASE                1070
#define IDC_USEDIGITS                   1071
#define IDC_USESYMBOLS                  1072
#define IDC_SPINLOWERCASE               1073
#define IDC_SPINUPPERCASE               1074
#define IDC_SPINDIGITS                  1075
#define IDC_SPINSYMBOLS                 1076
#define IDC_EASYVISION                  1077
#define IDC_ITEMTREE                    1078
#define IDC_GROUP                       1079
#define IDC_EXPORT_TEXT_PASSWORD        1081
#define ID_MENUITEM_SAVE                32771
#define ID_MENUITEM_EXIT                32772
#define ID_MENUITEM_ADD                 32773
#define ID_MENUITEM_EDIT                32774
#define ID_MENUITEM_DELETE              32775
#define ID_MENUITEM_COPYPASSWORD        32776
#define ID_MENUITEM_CLEARCLIPBOARD      32777
#define ID_MENUITEM_CHANGECOMBO         32778
#define ID_MENUITEM_BACKUPSAFE          32779
#define ID_MENUITEM_BACKUP              32779
#define ID_MENUITEM_OPTIONS             32780
#define ID_MENUITEM_ABOUT               32782
#define ID_MENUITEM_COPYUSERNAME        32787
#define ID_MENUITEM_OPEN                32793
#define ID_MENUITEM_NEW                 32794
#define ID_MENUTIME_SAVEAS              32795
#define ID_MENUITEM_RESTORE             32797
#define ID_MENUITEM_UPDATEBACKUPS       32798
#define ID_TOOLBUTTON_SAVE              32799
#define ID_TOOLBUTTON_COPYPASSWORD      32802
#define ID_TOOLBUTTON_EDIT              32803
#define ID_TOOLBUTTON_DELETE            32804
#define ID_TOOLBUTTON_ADD               32805
#define ID_TOOLBUTTON_HELP              32806
#define ID_TOOLBUTTON_COPYUSERNAME      32807
#define ID_TOOLBUTTON_NEW               32809
#define ID_TOOLBUTTON_OPEN              32810
#define ID_MENUITEM_FIND                32812
#define ID_TOOLBUTTON_CLEARCLIPBOARD    32813
#define ID_FILE_EXPORTTO_OLD1XFORMAT    32824
#define ID_FILE_EXPORTTO_PLAINTEXT      32825
#define ID_MENUITEM_LIST_VIEW           32826
#define ID_MENUITEM_TREE_VIEW           32827
#define ID_MENUITEM_ADDGROUP            32829
#define ID_MENUITEM_BROWSE              32830
#define ID_FILE_MRU_ENTRY1              40001
#define ID_FILE_MRU_ENTRY20             40020

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        207
#define _APS_NEXT_COMMAND_VALUE         32829
#define _APS_NEXT_CONTROL_VALUE         1082
#define _APS_NEXT_SYMED_VALUE           105
#endif
#endif

==> pwsafe-2.01-src.zip: pwsafe-2.01-src/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by PasswordSafe.rc
//
#define ID_BROWSE                       3
#define ID_CREATE_DB                    4
#define IDD_ABOUTBOX                    100
#define IDD_FIND                        101
#define IDD_PASSWORDSAFE_DIALOG         102
#define IDS_OUTPUTFILE                  102
#define ID_SYSMENU_ALWAYSONTOP          102
#define IDS_TEMPFILE                    103
#define IDS_COMPANY                     104
#define IDS_STATCOMPANY                 105
#define IDS_STATMESSAGE                 106
#define IDS_ALWAYSONTOP                 107
#define IDR_MAINFRAME                   128
#define IDR_ACCS                        128
#define IDD_KEYCHANGE_DIALOG            131
#define IDD_PASSKEYSETUP                132
#define IDD_SECURECLEAR                 133
#define IDI_IBUBBLE                     134
#define IDD_PASSKEYENTRY_FIRST          135
#define IDD_CONFIRMDELETE_DIALOG        136
#define IDD_OPTIONS                     137
#define IDD_EDIT                        139
#define IDD_MINIMIZECLEAR_DIALOG        141
#define IDD_ADD                         142
#define IDD_TRYAGAIN                    143
#define IDD_REMIND_SAVE                 144
#define IDB_PSLOGO                      148
#define IDB_CLOGO                       150
#define IDB_CTEXT                       151
#define IDD_CRYPTKEYENTRY               160
#define IDR_MAINMENU                    162
#define IDR_POPMENU                     166
#define IDD_QUERYSETDEF                 167
#define IDR_POPGROUP                    168
#define IDR_POPTREE                     169
#define IDD_QUERYADDNAME                183
#define IDD_USERNAMEENTRY               184
#define IDD_PASSKEYENTRY                185
#define IDR_MAINBAR                     187
#define IDB_CLOGO_SMALL                 189
#define IDI_CORNERICON                  191
#define IDD_PS_SECURITY                 194
#define IDD_PS_DISPLAY                  195
#define IDD_PS_USERNAME                 196
#define IDD_PS_PASSWORDPOLICY           197
#define IDD_PS_MISC                     198
#define IDB_NODE                        199
#define IDB_LEAF                        200
#define IDD_EXPORT_TEXT                 204
#define IDR_TOOLBAR1                    208
#define IDB_TOOLBAR1                    208
#define IDB_TOOLBAR2                    217
#define IDC_PASSWORD                    1000
#define IDC_ITEMLIST                    1000
#define IDC_OLDPASSKEY                  1001
#define IDC_NEWPASSKEY                  1002
#define IDC_CONFIRMNEW                  1003
#define IDC_TITLE                       1004
#define IDC_USERNAME                    1005
#define IDC_NOTES                       1006
#define IDC_SHOWPASSWORD                1008
#define IDC_CLEARCHECK                  1009
#define IDC_PASSKEY                     1010
#define IDC_DELITEM                     1010
#define IDC_VERIFY                      1012
#define IDC_CONFIRMDELETE               1014
#define IDC_CLEARBOARD                  1015
#define IDC_CONFIRMCOPY                 1016
#define IDC_TRYAGAIN                    1024
#define IDC_QUIT                        1025
#define IDC_OPEN                        1027
#define IDC_RANDOM                      1028
#define IDC_LOCKBASE                    1029
#define IDC_SAVEMINIMIZE                1030
#define IDC_DEFPWSHOW                   1031
#define IDC_DEFPWSHOWINEDIT             1031
#define IDC_USEDEFUSER                  1032
#define IDC_QUERYSETDEF                 1033
#define IDC_QUERYADDNAME                1034
#define IDC_DEFPWSHOWINLIST             1035
#define IDC_CRYPTKEY1                   1045
#define IDC_CRYPTKEY2                   1046
#define IDC_DEFUSERNAME                 1049
#define IDC_STATIC_USERNAME             1050
#define IDC_DEFPWLENGTH                 1051
#define IDC_MESSAGE                     1052
#define IDC_STATIC_DEFPWLENGTH          1052
#define IDC_QUERYCHECK                  1053
#define IDC_STATIC_RULES                1053
#define IDC_STATIC_MINLOWERCASE         1054
#define IDC_MAKEDEF                     1055
#define IDC_STATIC_MINUPPERCASE         1055
#define IDC_NEW                         1056
#define IDC_STATIC_MINDIGITS            1056
#define IDC_STATIC_ICON1                1057
#define IDC_STATIC_MINSYMBOLS           1057
#define IDC_MINLOWERCASE                1058
#define IDC_MINUPPERCASE                1059
#define IDC_STATIC_ICON2                1060
#define IDC_STATIC_LOGO                 1060
#define IDC_MINDIGITS                   1060
#define IDC_STATIC_ICON3                1061
#define IDC_MINSYMBOLS                  1061
#define IDC_FIND_TEXT                   1062
#define IDC_FIND_CS                     1063
#define IDC_STATUS                      1064
#define IDC_ALWAYSONTOP                 1065
#define IDC_STATIC_LOGOTEXT             1066
#define IDC_SAVEIMMEDIATELY             1066
#define IDC_SPIN1                       1068
#define IDC_USELOWERCASE                1069
#define IDC_USEUPPERCASE                1070
#define IDC_USEDIGITS                   1071
#define IDC_USESYMBOLS                  1072
#define IDC_SPINLOWERCASE               1073
#define IDC_SPINUPPERCASE               1074
#define IDC_SPINDIGITS                  1075
#define IDC_SPINSYMBOLS                 1076
#define IDC_EASYVISION                  1077
#define IDC_ITEMTREE                    1078
#define IDC_GROUP                       1079
#define IDC_EXPORT_TEXT_PASSWORD        1081
#define IDC_USEHEXDIGITS                1082
#define ID_MENUITEM_SAVE                32771
#define ID_MENUITEM_EXIT                32772
#define ID_MENUITEM_ADD                 32773
#define ID_MENUITEM_EDIT                32774
#define ID_MENUITEM_DELETE              32775
#define ID_MENUITEM_COPYPASSWORD        32776
#define ID_MENUITEM_CLEARCLIPBOARD      32777
#define ID_MENUITEM_CHANGECOMBO         32778
#define ID_MENUITEM_BACKUPSAFE          32779
#define ID_MENUITEM_BACKUP              32779
#define ID_MENUITEM_OPTIONS             32780
#define ID_MENUITEM_ABOUT               32782
#define ID_MENUITEM_COPYUSERNAME        32787
#define ID_MENUITEM_OPEN                32793
#define ID_MENUITEM_NEW                 32794
#define ID_MENUTIME_SAVEAS              32795
#define ID_MENUITEM_RESTORE             32797
#define ID_MENUITEM_UPDATEBACKUPS       32798
#define ID_TOOLBUTTON_SAVE              32799
#define ID_TOOLBUTTON_COPYPASSWORD      32802
#define ID_TOOLBUTTON_EDIT              32803
#define ID_TOOLBUTTON_DELETE            32804
#define ID_TOOLBUTTON_ADD               32805
#define ID_TOOLBUTTON_HELP              32806
#define ID_TOOLBUTTON_COPYUSERNAME      32807
#define ID_TOOLBUTTON_NEW               32809
#define ID_TOOLBUTTON_OPEN              32810
#define ID_MENUITEM_FIND                32812
#define ID_TOOLBUTTON_CLEARCLIPBOARD    32813
#define ID_FILE_EXPORTTO_OLD1XFORMAT    32824
#define ID_FILE_EXPORTTO_PLAINTEXT      32825
#define ID_MENUITEM_LIST_VIEW           32826
#define ID_MENUITEM_TREE_VIEW           32827
#define ID_MENUITEM_ADDGROUP            32829
#define ID_MENUITEM_BROWSE              32830
#define ID_FILE_MRU_ENTRY1              40001
#define ID_FILE_MRU_ENTRY20             40020

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NEXT_RESOURCE_VALUE        218
#define _APS_NEXT_COMMAND_VALUE         32830
#define _APS_NEXT_CONTROL_VALUE         1082
#define _APS_NEXT_SYMED_VALUE           105
#endif
#endif
